<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
*
 ********************************************************************************/


$mod_strings = array(

'LBL_PRICEBOOK_INFORMATION'=>'Price Book Information:',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_DESCRIPTION_INFORMATION'=>'Description Name:',
//Mapping for price book
'Price Book Name'=>'Price Book Name',
'Product Name'=>'Product Name',
'Active'=>'Active',
'Description'=>'Description',
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',
'LBL_LIST_PRODUCT_NAME'=>'Product Name',
'LBL_PRODUCT_CODE'=>'Part Number',
'LBL_PRODUCT_UNIT_PRICE'=>'Unit Price',
'LBL_PB_LIST_PRICE'=>'List Price',
'LBL_ACTION'=>'Action',
'PriceBook'=>'Price Book',

// Added after 5.0.4 GA
'Currency'=>'Currency',

// Module Sequence Numbering
'PriceBook No' => 'PriceBook No',
// END
);



?>
